@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 """Configuration introspection and defaults."""
 from __future__ import absolute_import, unicode_literals
+
 import sys
 from collections import deque, namedtuple
 from datetime import timedelta
+
 from celery.five import items, keys, python_2_unicode_compatible
 from celery.utils.functional import memoize
 from celery.utils.serialization import strtobool
@@ -152,6 +154,7 @@ NAMESPACES = Namespace(
     redis=Namespace(
         __old__=old_ns('celery_redis'),
 
+        backend_use_ssl=Option(type='dict'),
         db=Option(type='int'),
         host=Option(type='string'),
         max_connections=Option(type='int'),
@@ -178,6 +181,13 @@ NAMESPACES = Namespace(
         persistent=Option(None, type='bool'),
         serializer=Option('json'),
     ),
+    elasticsearch=Namespace(
+        __old__=old_ns('celery_elasticsearch'),
+
+        retry_on_timeout=Option(type='bool'),
+        max_retries=Option(type='int'),
+        timeout=Option(type='float'),
+    ),
     riak=Namespace(
         __old__=old_ns('celery_riak'),
 
@@ -277,7 +287,7 @@ NAMESPACES = Namespace(
             'WARNING', old={'celery_redirect_stdouts_level'},
         ),
         send_task_events=Option(
-            False, type='bool', old={'celeryd_send_events'},
+            False, type='bool', old={'celery_send_events'},
         ),
         state_db=Option(),
         task_log_format=Option(DEFAULT_TASK_LOG_FMT),
