@@ -8,8 +8,7 @@ from billiard.einfo import ExceptionInfo
 from kombu.exceptions import OperationalError
 from kombu.utils.uuid import uuid
 
-from celery import current_app, group
-from celery import states
+from celery import current_app, group, states
 from celery._state import _task_stack
 from celery.canvas import signature
 from celery.exceptions import Ignore, MaxRetriesExceededError, Reject, Retry
@@ -19,6 +18,7 @@ from celery.result import EagerResult
 from celery.utils import abstract
 from celery.utils.functional import mattrgetter, maybe_list
 from celery.utils.imports import instantiate
+from celery.utils.nodenames import gethostname
 from celery.utils.serialization import raise_with_context
 
 from .annotations import resolve_all as resolve_all_annotations
@@ -123,7 +123,6 @@ class Context(object):
             'expires': self.expires,
             'soft_time_limit': limit_soft,
             'time_limit': limit_hard,
-            'reply_to': self.reply_to,
             'headers': self.headers,
             'retries': self.retries,
             'reply_to': self.reply_to,
@@ -564,9 +563,17 @@ class Task(object):
         args = request.args if args is None else args
         kwargs = request.kwargs if kwargs is None else kwargs
         options = request.as_execution_options()
-        options.update(
-            {'queue': queue} if queue else (request.delivery_info or {}),
-        )
+        if queue:
+            options['queue'] = queue
+        else:
+            delivery_info = request.delivery_info or {}
+            exchange = delivery_info.get('exchange')
+            routing_key = delivery_info.get('routing_key')
+            if exchange == '' and routing_key:
+                # sent to anon-exchange
+                options['queue'] = routing_key
+            else:
+                options.update(delivery_info)
         return self.signature(
             args, kwargs, options, type=self, **extra_options
         )
@@ -597,7 +604,7 @@ class Task(object):
         Arguments:
             args (Tuple): Positional arguments to retry with.
             kwargs (Dict): Keyword arguments to retry with.
-            exc (Exception): Custom exception to report when the max restart
+            exc (Exception): Custom exception to report when the max retry
                 limit has been exceeded (default:
                 :exc:`~@MaxRetriesExceededError`).
 
@@ -719,6 +726,7 @@ class Task(object):
             'is_eager': True,
             'logfile': logfile,
             'loglevel': loglevel or 0,
+            'hostname': gethostname(),
             'callbacks': maybe_list(link),
             'errbacks': maybe_list(link_error),
             'headers': headers,
@@ -841,7 +849,7 @@ class Task(object):
             chord = None
 
         if self.request.chain:
-            for t in self.request.chain:
+            for t in reversed(self.request.chain):
                 sig |= signature(t, app=self.app)
 
         sig.freeze(self.request.id,
@@ -997,4 +1005,6 @@ class Task(object):
     @property
     def __name__(self):
         return self.__class__.__name__
-BaseTask = Task  # compat alias
+
+
+BaseTask = Task  # noqa: E305 XXX compat alias
